/* this file is part of libccc, criawips' cairo-based canvas
 *
 * AUTHORS
 *       Sven Herzberg        <herzi@gnome-de.org>
 *
 * Copyright (C) 2005,2006 Sven Herzberg
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef CCC_H
#define CCC_H

#include <ccc/cc-brush.h>
#include <ccc/cc-brush-color.h>
#include <ccc/cc-cairo.h>
#include <ccc/cc-camera.h>
#include <ccc/cc-caret.h>
#include <ccc/cc-circle.h>
#include <ccc/cc-color.h>
#include <ccc/cc-d-rect.h>
#include <ccc/cc-gradient.h>
#include <ccc/cc-enumerations.h>
#include <ccc/cc-item.h>
#include <ccc/cc-item-view.h>
#include <ccc/cc-line.h>
#include <ccc/cc-linear-gradient.h>
#include <ccc/cc-pixbuf.h>
#include <ccc/cc-printer.h>
#include <ccc/cc-radial-gradient.h>
#include <ccc/cc-rectangle.h>
#include <ccc/cc-rounded-rectangle.h>
#include <ccc/cc-text.h>
#include <ccc/cc-shape.h>
#include <ccc/cc-simple-item.h>
#include <ccc/cc-utils.h>
#include <ccc/cc-view.h>
#include <ccc/cc-view-cell-renderer.h>
#include <ccc/cc-view-png.h>
#include <ccc/cc-view-widget.h>

#endif /* !CCC_H */

